pymodaq_plugins_uniblitz (Uniblitz)
##########################################

PyMoDAQ plugin for Uniblitz shutters


Authors
=======

* Matthieu Guer  (matthieu.guer@cea.fr)
* Romain Géneaux (romain.geneaux@cea.fr)


Instruments
===========

Below is the list of instruments included in this plugin

Actuators
+++++++++

* **VLM1**: control of Uniblitz VLM1 Shutter Interface Module by USB. Very basic functionality to switch the shutter, without reading the actual state of the shutter.

